package require snit 0.91
package require SyncTimer 1.0

package provide wallclock 1.0

##  wallclock.tcl
##
##  A clock widget, synchronized with system-clock
##
##  Copyright (c) 2005 <Irrational Numbers> : <aburatti@libero.it>
##
##  NOTE: package "snit" (v0.91) is required.
##   It is freely downloadable from the Web:
##       http://www.wjduquette.com/snit
##   Now is part of the official "tcllib"
##
##  This program is free software; you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation.
##

#
# How to use wallclock:
#   Read "wallclock.txt" for detailed info.
#   Sample code in provided in "demo*.tcl".
#


::snit::widgetadaptor wallclock { 
    variable ID          0
    variable ClockStatus off

    option -utc        -default false
    option -timeformat -default "%H:%M:%S"
    option -interval   -default "1 sec"

    delegate method * to hull
    delegate option * to hull except -textvariable
    
    constructor {args} {
        installhull using label
        $win configurelist $args
        $win Display $options(-timeformat)
    }
    
    destructor {
        $win stop
    }
    
     # private
    method Display {fmt} {
        $win configure -text [clock format [clock seconds] -format $fmt -gmt $options(-utc)]               
    }
        
    onconfigure -interval {value} {
         # validate; let the error raise ..
        clock scan $value
        set options(-interval) $value
    }

    method start {} {
        $win stop
        set ID [SyncTimer::every $options(-interval) "00:00:00" \
             [mymethod Display $options(-timeformat)]]        
        set ClockStatus on
    }
    
    method stop {} {
        catch {SyncTimer::cancel $ID}
        set ClockStatus off
    }

    method getClockStatus {} {
       return $ClockStatus
    }
}
